//==============================================================
// FILENAME: cogging.h
//
// This is the header file that defines the constants and functions
// for the Cogging control logic implemented in the FPGA.
//
//

#ifndef _COGHDR2
#define _COGHDR2

#define CLK_BUFSIZE 16
#define ADC_BUFSIZE 12
#define SDRAM_BUFSIZE 4
#define FLASH_BUFSIZE 256
#define MAX2_BUFSIZE 12
#define FPGA_BUFSIZE 256
#define SPORT_BUFSIZE 10
#define CF_BUFSIZE 9

#define DSPMEM_UPPR_LMT  	   0x100000		
#define SDRAM_UPPR_LMT  	   0x140000
#define Flash_UPPR_LMT  	   0x580000
#define FPGA_UPPR_LMT	  	   0x1000000

#define DSP_DM_BASE_ADDRESS 0xB8000		// these are 32-bit addresses

//--------------------------------------------------------------------------
// SDRAM Memory Assignments ================================================
#define SDRAM_BASE_ADDRESS 0x00200000	// these are 32-bit addresses
										// The Acquire_Channel function stores at SDRAM_BASE_ADDRESS
										// Acquire_Channel uses 65535 memory locations.
#define CNTRL_REG_BASE	0x00220000		// Slot 0 Address = 0x20480000
#define PARAM_MEM_BASE 	0x00230000      // Slot 0 Address = 0x204C0000
//===========================================================================


#define FLASH_BASE_ADDRESS 0x04000000
#define FLASH_SECTOR_SIZE  0x00020000

// NOTE: Flash Sectors 0-1 are used to store DSP code.
//       Flash Sectors 2-15 are used to store FPGA code.
//       Flash Sector  16   is used by the Parallel Flash FPGA Loader for settings.

							   
#define MAX2_BASE_ADDRESS  0x08000000


#define VXI_ADDRESS_REG	   0x0800000a
#define VXI_DATA_REG  	   0x08000009
#define VIRPT_REG	  	   0x08000000
#define MSG_REG0	  	   0x08000001
#define MSG_REG1	  	   0x08000002
#define MSG_REG2	  	   0x08000003
#define MSG_REG3	  	   0x08000004
#define MSG_REG4	  	   0x08000005
#define MSG_REG5	  	   0x08000006
#define MSG_REG6	  	   0x08000007
#define MSG_REG7	  	   0x08000008


//-------------------------------------------------------------------------
// FPGA Memory Assignments ================================================
#define FPGA_BASE_ADDRESS  		0x0C000000
#define FPGA_DAQ_CTL	  	   	0x0C01C800
#define FPGA_DAQ_BASE_ADDR 	   	0x0C020000


//FPGA pointers for testing
#define TEST_POINT_1 	0x0C004010 //SLOT_0_ADDRESS = 0x21610040
#define TEST_POINT_2 	0x0C004011 //SLOT_0_ADDRESS = 0x21610044
#define TEST_POINT_3 	0x0C004012 //SLOT_0_ADDRESS = 0x21610048
#define TEST_POINT_4 	0x0C004013 //SLOT_0_ADDRESS = 0x2161004C
#define TEST_POINT_5 	0x0C004014 //SLOT_0_ADDRESS = 0x21610050
#define TEST_POINT_6 	0x0C004015 //SLOT_0_ADDRESS = 0x21610054
#define TEST_POINT_7 	0x0C004016 //SLOT_0_ADDRESS = 0x21610058
#define TEST_POINT_8 	0x0C004017 //SLOT_0_ADDRESS = 0x2161005C

//==========================================================================

#endif //_COGHDR
