/* This program enables SPI in Master transmit and receive mode. The SPI transmit
signal is connected to DPI pin 1 */

#include <Cdef21369.h>
#include <def21369.h>
#include <21369.h>
#include "cogging.h"
#include "mfctest_c.h"


/* Init SPI MASTER TX */

void    initSPI(void)
	{

*pSPICTL = 0;
*pSPIFLG = 0;

/* Sets the Baud rate (320.33 kHz) for SPI */
*pSPIBAUD = 0x100;

// Initialize SPI port for CLK & ADC communication

*pSPICTL =  OPD|		//Open Drain output
		 	DMISO|		//Disable MISO on transfers
		  	WL32|		//32-bit words
		 	SPIMS|		//Master mode (internal SPICLK)
		  	MSBF|		//Most significant byte first
		 	SPIEN|		//Enable SPI port
			TIMOD1|
		    GM;			//Initialize SPI port to begin transmitting 
		 				//when there is a core write to the TXSPI register



	}//initSPI.end:


void SPI_Write_IC(unsigned IC_num, unsigned wdata)

	{

    switch (IC_num)					// Chip select IC to write to
    	{
    	     
	    case    0:  *pSPIFLG = DS2EN|DS1EN|DS0EN;   break;//ClkIC_CS
 	    case    1:  *pSPIFLG = DS2EN|DS1EN;         break;//ADC1_CS
	    case    2:  *pSPIFLG = DS2EN|DS0EN;         break;//ADC2_CS  
	    case    3:  *pSPIFLG = DS2EN;               break;//ADC3_CS  
	    case    4:  *pSPIFLG = DS1EN|DS0EN;         break;//ADC4_CS
	    default:                                    break;
	    
    	}

    *pTXSPI = wdata;              	// Send write data through SPI.     
    while (((TXS)&(*pSPISTAT))) {;}	// Wait for transmit buffer to be empty (TXS=0) 
	Delay(20000);					// Additional delay
    
	}//SPI_Write_IC.END
	
	
	
	
unsigned SPI_Read_IC(unsigned IC_num, unsigned addr)

	{
	    unsigned rdata;

    switch (IC_num)					// Chip select IC to write to
    	{
    	     
	    case    0:  *pSPIFLG = DS2EN|DS1EN|DS0EN;   break;//ClkIC_CS
 	    case    1:  *pSPIFLG = DS2EN|DS1EN;         break;//ADC1_CS
	    case    2:  *pSPIFLG = DS2EN|DS0EN;         break;//ADC2_CS  
	    case    3:  *pSPIFLG = DS2EN;               break;//ADC3_CS  
	    case    4:  *pSPIFLG = DS1EN|DS0EN;         break;//ADC4_CS

	    default:                                    break;
	    
    	}


    *pTXSPI = 0xA000FFFF | (addr<<16);// Transmit address to read in third byte of command word
    while ((TXS)&(*pSPISTAT)) {;}	  // Wait for transmit buffer to be empty (TXS=0) 
	Delay(20000);					  // Additional delay
	rdata = *pRXSPI;				  // Read receive buffer

	return ( (rdata>>8) & 0xFF );	  // Extract data requested and return
	
	}//SPI_Read_IC.end
	
	
	

void    Delay(long int   count)
	{
    		long int i;
    
    	for (i=0; i<count; i++)
    		{   
        		asm("nop;");
        		asm("nop;");
        		asm("nop;");
    		}	
	}//Delay.end

