#include <Cdef21369.h>
#include <def21369.h>
#include <21369.h>
#include "cogging.h"
#include "mfctest_c.h"


/*****************************************************************************************************/
// Clock Distribution Chip Setup
//
// The 32 bit words loaded into the serial port of the AD9510 Clock Distribution chip consist of
// 16 bit Instruction Word (MSB), followed by two 8 bit Data Bytes.  The most significant data byte
// is the setting for the register addressed (N) in the Instruction Word.  The last data byte is the 
// setting for the register previous (N-1) addressed in the Instruction Word.
//
// The Instruction Word
// ~~~~~~~~~~~~~~~~~~~~
//   | I15  | I14  | I13  |  I12  |  I11  |  I10  | I9   | I8   | I7   | I6 | I5 | I4 | I3 | I2 | I1 | I0 |
//   +------+------+------+-------+-------+-------+------+------+------+----+----+----+----+----+----+----+
//   | R/W# | W1=0 | W0=1 | A12=0 | A11=0 | A10=0 | A9=0 | A8=0 | A7=0 | A6 | A5 | A4 | A3 | A2 | A1 | A0 |
//
//
//   Example:  0 x 2 0 4 D 8 0 7 7
//                 
//        Write so I15 = 0
//        2 data bytes follow so [I14, I13] = [0, 1]
//        A[12...8] = 0
//                        So we have 0010 0000 for the first byte (MSB)
//        The second byte I[7...0] is then the register (N) address, 0x4D.
//
// The 2 Data Bytes
// ~~~~~~~~~~~~~~
//   The 2 data bytes in the example above are 0x80 to be written to register 0x4D (N)
//   and 0x77 to be written to register 0x4C (N-1).
//
//   See the AD9510 datasheet for definition of the data bytes.


unsigned ClkChip_buf[CLK_BUFSIZE] ={
									0x20009000, // (00)Makes SDIO pin bidirectional and SDO inactive
									
	 								0x203D0808,	// (3D)Output 0: PECL logic, on, .810 V output level ADC2
												// (3C)Output 1: PECL logic, on, .810 V output level ADC1
									0x203F0808,	// (3F)Output 3: PECL logic, on, .810 V output level ADC3
												// (3E)Output 2: PECL logic, on, .810 V output level ADC4
															
					   				0x20410A0A,	// (41)Output 5: CMOS logic, on,  3.5 ma output level, 100 ohms Termination, DAC2
					   							// (40)Output 4: CMOS logic, on,  3.5 ma output level, 100 ohms Termination, DAC1
					   				0x20430202,	// (43)Output 7: LVDS logic, on,  3.5 ma output level, 100 ohms Termination, FPGA
					   							// (42)Output 6: LVDS logic, on,  3.5 ma output level, 100 ohms Termination, ADC5
					   							
					   				0x20450100,	// Input Clock: 01 - CLK1, 65 MHz crystal || 00 - CLK2, LO External Clock 
					   							// Address 0x44 not used 
					   							
					   				0x20490011,	// (49)Output 0: phase=0, ADC2 clock
					   							// (48)Output 0: Divide ratio 4, ADC2 clock (65 / 4 = 16.25)
					   				0x204B0011,	// (4B)Output 1: phase=0, ADC1 clock
					   							// (4A)Output 1: Divide ratio 4, ADC1 clock
					   				0x204D0011,	// (4D)Output 2: phase=0, ADC4 clock
					   							// (4C)Output 2: Divide ratio 4, ADC4 clock
					   				0x204F0011,	// (4F)Output 3: phase=0, ADC3 clock
					   							// (4E)Output 3: Divide ratio 4, ADC3 clock
					   							
					   				0x20518000,	// (51)Output 4: phase=0, DAC1 clock ** DIVIDER BYPASSED **
					   							// (50)Output 4: Divide ratio 2, DAC1 clock
					   				0x20538000,	// (53)Output 5: phase=0, DAC2 clock ** DIVIDER BYPASSED **
					   							// (52)Output 5: Divide ratio 2, DAC2 clock
					   							
					   				0x20550011,	// (55)Output 6: phase=0, ADC5 clock
					   							// (54)Output 6: Divide ratio 4, ADC5 clock
					   							
					   				0x20578000,	// (57)Output 7: phase=0, FPGA clock ** DIVIDER BYPASSED **
					   							// (56)Output 7: Divide ratio 2, FPGA clock
					   				0x20582580, // (58)Function pin: SYNCB
					   							// (57)Output 7: phase=0, FPGA clock
					   				0x205A0100};// Transfer buffer data to control registers
					   							// Address 0x59 not used
	


unsigned ADC1_buf[ADC_BUFSIZE] = {	0x20053F0F,	// Channels A -> D, DCO, & FCO  written to next
												// Channels E -> H written to next
									0x20160621,	// 360 deg. clock phase shift relative to data
												// Set ADC output drivers termination to 100 ohms
									0x20FF0100,	// Transfer data from master shift register to slave(s)
												// Address 0xFE not supported								
									0x20050103,	// Channel A written to next
												// Channels E and F written to next
									0x20140500, // Specific channels output inverted
												// Address 0x13 not supported
									0x20FF0100,	// Transfer data from master shift register to slave(s)
												// Address 0xFE not supported																		
									0x20050F0F,	// Channels A -> D written to next		
												// Channels E -> H written to next
//									0x200D0700,	// Output test mode pattern: one/zero word toggle
									0x200D0000,	// Output test mode pattern: CHECKER BOARD
//									0x200D0900,	// Output test mode pattern: 0/1 bit toggle
//									0x200D0000,	// Output test mode pattern: off
												// Address 0x0C not supported										
									0x20220000,	// No power down for specific channel
												// Default setting of 0x00 for address 0x21
									0x20FF0100,	// Transfer data from master shift register to slave(s)
												// Address 0xFE not supported								
									0x20090100,	// Duty cycle stabilizer on		
												// Power down setting: chip run
									0x20FF0100};// Transfer data from master shift register to slave(s)
												// Address 0xFE not supported								
											

unsigned ADC2_buf[ADC_BUFSIZE] = {	0x20053F0F,	// Channels A -> D, DCO, & FCO  written to next
												// Channels E -> H written to next
									0x20160621,	// 360 deg clock phase shift relative to data
												// Set ADC output drivers termination to 100 ohms
									0x20FF0100,	// Transfer data from master shift register to slave(s)
												// Address 0xFE not supported								
									0x20051800,	// Channel FCO and channel D written to next
												// No other channels affected
									0x20140500, // Specific channels output inverted
												// Address 0x13 not supported
									0x20FF0100,	// Transfer data from master shift register to slave(s)
												// Address 0xFE not supported																		
									0x20050F0F,	// Channels A -> D written to next		
												// Channels E -> H written to next
									0x20220000,	// No power down for specific channel
												// Default setting of 0x00 for address 0x21
									0x20FF0100,	// Transfer data from master shift register to slave(s)
												// Address 0xFE not supported								
									0x200D0000,	// Output test mode pattern: off
												// Address 0x0C not supported
									0x20090100,	// Duty cycle stabilizer on		
												// Power down setting: chip run
									0x20FF0100};	// Transfer data from master shift register to slave(s)
												// Address 0xFE not supported								
											


unsigned ADC3_buf[ADC_BUFSIZE] = {	0x20053F0F,	// Channels A -> D, DCO, & FCO  written to next
												// Channels E -> H written to next
									0x20160821,	// 360 deg clock phase shift relative to data
												// Set ADC output drivers termination to 100 ohms
									0x20FF0100,	// Transfer data from master shift register to slave(s)
												// Address 0xFE not supported								
									0x2005000C,	// No channels at this address written to next
												// Channels H and G written to next
									0x20140500, // Specific channels output inverted
												// Address 0x13 not supported
									0x20FF0100,	// Transfer data from master shift register to slave(s)
												// Address 0xFE not supported																		
									0x20050F0F,	// Channels A -> D written to next		
												// Channels E -> H written to next
									0x20220000,	// No power down for specific channel
												// Default setting of 0x00 for address 0x21
									0x20FF0100,	// Transfer data from master shift register to slave(s)
												// Address 0xFE not supported								
									0x200D0000,	// Output test mode pattern: on checkerboard
												// Address 0x0C not supported
									0x20090100,	// Duty cycle stabilizer on		
												// Power down setting: chip run
									0x20FF0100};// Transfer data from master shift register to slave(s)
												// Address 0xFE not supported																	
											
unsigned ADC4_buf[ADC_BUFSIZE] = {	0x20053F0F,	// Channels A -> D, DCO, & FCO  written to next
												// Channels E -> H written to next
//									0x20160421,	// 240 deg. clock phase shift relative to data
									0x20160621,	// 60 deg. clock phase shift relative to data
												// Set ADC output drivers termination to 100 ohms
									0x20FF0100,	// Transfer data from master shift register to slave(s)
												// Address 0xFE not supported								
									0x20050401,	// Channel C written to next
												// Channel E to next
									0x20140500, // Specific channels output inverted
												// Address 0x13 not supported
									0x20FF0100,	// Transfer data from master shift register to slave(s)
												// Address 0xFE not supported																		
									0x20050F0F,	// Channels A -> D written to next		
												// Channels E -> H written to next
									0x20220000,	// No power down for specific channel
												// Default setting of 0x00 for address 0x21
									0x20FF0100,	// Transfer data from master shift register to slave(s)
												// Address 0xFE not supported								
//									0x200D0700,	// Output test mode pattern: one/zero word toggle
//									0x200D0B00,	// Output test mode pattern: one bit 
//									0x200D0900,	// Output test mode pattern: 0/1 bit toggle
									0x200D0000,	// Output test mode pattern: CHECKER BOARD
//									0x200D0000,	// Output test mode OFF
												// Address 0x0C not supported
									0x20090100,	// Duty cycle stabilizer on		
												// Power down setting: chip run
									0x20FF0100};// Transfer data from master shift register to slave(s)
												// Address 0xFE not supported								

												
void initMFCBoard(void)

	{

    initPLL_SDRAM();
    init_ASM(); // Interrupts enabled in this routine.
    init_ASM_Stack();
    initDAI();
    initDPI();
    initSPI();
    initSPORT();
    

	}// initMFCBoard.end
	

void init_SPI_Devices(void)

	{
	 	unsigned index;

// Configure Clock Chip	 	
	 		 	
	 	for (index = 0; index < CLK_BUFSIZE; index++)
	 		{
	 		    SPI_Write_IC(0, ClkChip_buf[index]);
	 		}

// Configure ADC1, Use separate loops for each ADC to allow different buffer sizes

	 	for (index = 0; index < ADC_BUFSIZE; index++)
	 		{
	 		    SPI_Write_IC(1, ADC1_buf[index]);
	 		}
	 		
// Configure ADC2

	 	for (index = 0; index < ADC_BUFSIZE; index++)
	 		{
	 		    SPI_Write_IC(2, ADC2_buf[index]);
	 		}
	 		
// Configure ADC3	 		

	 	for (index = 0; index < ADC_BUFSIZE; index++)
	 		{
	 		    SPI_Write_IC(3, ADC3_buf[index]);
	 		}
	 		
// Configure ADC4	 		

	 	for (index = 0; index < ADC_BUFSIZE; index++)
	 		{
	 		    SPI_Write_IC(4, ADC4_buf[index]);
	 		}
	 			 			 			 			 		
	}//init_SPI_Devices.End

