// The following definition allows the SRU macro to check for errors. Once the routings have
// been verified, this definition can be removed to save some program memory space.
// The preprocessor will issue a warning stating this when using the SRU macro without this
// definition
#define SRUDEBUG  // Check SRU Routings for errors.
#include <SRU.h>
#include <sru21369.h>

void initDPI(void) 
	{

SRU(SPI_MOSI_O,DPI_PB01_I); // SPI_MOSI signal is connected to DPI pin 1
SRU(SPI_MOSI_PBEN_O,DPI_PBEN01_I);
SRU(DPI_PB01_O,SPI_MISO_I); 	// connect the pin buffer 2 output signal to the SPI_MISO

SRU(UART0_TX_O,DPI_PB02_I); // UART transmit signal is connected to DPI pin 2
SRU(HIGH,DPI_PBEN02_I); 
   
SRU(DPI_PB07_O,UART0_RX_I); // connect the pin buffer output signal to the UART0 receive
SRU(LOW,DPI_PB07_I);
SRU(LOW,DPI_PBEN07_I);      // disables DPI pin7 as input

SRU(SPI_CLK_O,DPI_PB03_I);  // SPI_CLK signal is connected to DPI pin 3
SRU(SPI_CLK_PBEN_O,DPI_PBEN03_I);

SRU(SPI_FLG0_O,DPI_PB04_I);  // SPI_FLG0 (SPI_CHIP_CSIn0) signal is connected to DPI pin 4
SRU(SPI_FLG0_PBEN_O,DPI_PBEN04_I);

SRU(SPI_FLG1_O,DPI_PB05_I);  // SPI_FLG1 (SPI_CHIP_CSIn1) signal is connected to DPI pin 5
SRU(SPI_FLG1_PBEN_O,DPI_PBEN05_I);

SRU(SPI_FLG2_O,DPI_PB06_I);  // SPI_FLG2 (SPI_CHIP_CSIn2) signal is connected to DPI pin 6
SRU(SPI_FLG2_PBEN_O,DPI_PBEN06_I);

// FLAGS0-15 are configured as inputs or outputs in the FLAGS register
// If a particular flag is an input then the corresponding FLAGX_PBEN_O should be set low automatically
// If the direction is not going to change we can just set it to LOW or HIGH for input or output

SRU(DPI_PB08_O,FLAG4_I); 			// connect the pin buffer 8 output signal (DSP_IRQ_MUX0) to FLAG4
SRU(FLAG4_PBEN_O,DPI_PBEN08_I);       // enables DPI pin8 as input

SRU(DPI_PB09_O,FLAG5_I); 			// connect the pin buffer 9 output signal (DSP_IRQ_MUX1) to FLAG5
SRU(FLAG5_PBEN_O,DPI_PBEN09_I);      	// enables DPI pin9 as input

SRU(DPI_PB13_O,FLAG6_I); 			// connect the pin buffer 13 output signal (DSP_IRQ_MUX2) to FLAG6
SRU(FLAG6_PBEN_O,DPI_PBEN13_I);  		// enables DPI pin13 as input

SRU(FLAG7_O,DPI_PB10_I); 			// connect the FLAG7 to pin buffer 10 input signal (DSP_FPGA_Spare0) 
SRU(FLAG7_PBEN_O,DPI_PBEN10_I);       // enables DPI pin10 as output

SRU(DPI_PB11_O,FLAG8_I); 			// connect the pin buffer 11 output signal (DSP_FPGA_Spare1) to FLAG8
SRU(FLAG8_PBEN_O,DPI_PBEN11_I);  		// enables DPI pin11 as input

SRU(FLAG9_O,DPI_PB12_I); 			// connect the FLAG9 to pin buffer 12 input signal (DSP_MAX2_Spare0)
SRU(FLAG9_PBEN_O,DPI_PBEN12_I);  		// enables DPI pin12 as output

SRU(FLAG10_O,DPI_PB14_I); 			// connect the FLAG10 to pin buffer 14 input signal (DSP_BREQ) 
SRU(FLAG10_PBEN_O,DPI_PBEN14_I);      // enables DPI pin14 as output

	}//initDPI.end

