/*   DSP Parameter Memory header file  */
 
#ifndef _PARAMHDR2
#define _PARAMHDR2

#include <string.h>
#include <stdio.h>


//	Parameters with values that may be changed during runtime are written
//	into the SDRAM.  Routines on the DSP update registers in the FPGA 
//  where control processes employ the parameter, and the parameters are
//  periodically saved in non-volatile Flash memory.  

//  The number of such parameters is defined as NFLTPARAMS and NINTPARAMS.


//	Each parameter must have upper and lower limits as well as a default value
//	defined since updates to the runtime values are compared against these values.

#define NFLTPARAMS 1		// set the number of float parameters
#define NINTPARAMS 9		// set the number of integer parameters plus integer curves
#define MAXMSGLEN  512


//The TEMPORARY DEFINITIONS -- FPGA Parameter registers at offset of 0x4000 (A32/D32)
//FPGA_BASE_ADDRESS = 0x0C000000
#define P0_OFFSET  0x0C004000	//SLOT_0_ADDRESS = 0x21610000
#define P1_OFFSET  0x0C004001	//SLOT_0_ADDRESS = 0x21610004
#define P2_OFFSET  0x0C004002	//SLOT_0_ADDRESS = 0x21610008
#define P3_OFFSET  0x0C004003	//SLOT_0_ADDRESS = 0x2161000C
#define P4_OFFSET  0x0C004004	//SLOT_0_ADDRESS = 0x21610010
#define P5_OFFSET  0x0C004005	//SLOT_0_ADDRESS = 0x21610014
#define P6_OFFSET  0x0C004006	//SLOT_0_ADDRESS = 0x21610018
#define P7_OFFSET  0x0C004007	//SLOT_0_ADDRESS = 0x2161001C
#define P8_OFFSET  0x0C008000	//SLOT_0_ADDRESS = 0x21620000


	int		update_flash_flag;
	
// =====================================================================================
// ############## OVERALL PARAMETER MEMORY STRUCTURE AND VARIABLES #####################

struct int_params
{
	char		desc[128];  /*description of the paramter (string)*/
	int			dim;        /*array size of the parameter or curve */
	int			ul;			/*upper limit on value*/
	int			ll;			/*lower limit on value*/
	int			dflt;		/*default value */
	int			flag;		/*update flag*/
	int			rdg;		/*location of parameter reading (offset from "PARAM_MARKER")*/
	int			set;		/*location of parameter setting (offset from "PARAM_MARKER")*/
	int			*data;      /*not used. only makes ppc and dsp struct sizes the same*/
};

struct flt_params
{
	char		desc[128];  /*description of the paramter (string)*/
	int			dim;        /*array size of the parameter or curve */
	float		ul;			/*upper limit on value*/
	float		ll;			/*lower limit on value*/
	float		dflt;		/*default value */
	int			flag;		/*update flag*/
	int			rdg;		/*location of parameter reading (offset from "PARAM_MARKER")*/
	int			set;		/*location of parameter setting (offset from "PARAM_MARKER")*/
	float		*data;      /*not used. only makes ppc and dsp struct sizes the same*/
};

struct parameter_mem			  
{
	int			msgsem; 		/* semaphor for message buffer*/
	int         nChar; 			/* number of characters in the buffer*/
	char		msg[MAXMSGLEN]; /* Message buffer for communicating with Crate Controller terminal*/

	int			nint_params;    /* Number of integer parameters and curves.*/
	int			nflt_params;	/* Number of floating point parameters and curves*/
	
	int	        PARAM_MARKER;    
	struct int_params ip[NINTPARAMS]; /*An array of integer parameters*/
	struct flt_params fp[NFLTPARAMS]; /*An array of float parameters*/
	
	int 		DATA_MARKER;
		
};

/* ------------ Pointer to Parameter Memory Structure ------------*/
	struct parameter_mem *prm;

//=====================================================================================
// ########################### LOCAL DSP PARAMETER STRUCTURES ########################
	
struct dm_int_params
{
	int				dim;        /*array size of the parameter or curve */
	int				ll;			/*lower limit on value*/
	int				ul;			/*upper limit on value*/
	int				dflt;		/*default value */
	int				*sm_rdg;    /*pointer to parameter reading in shared memory*/
	int				*sm_set;	/*pointer to parameter setting in shared memory*/
	int				*flsh_val;  /*pointer to the flash memory storage*/
	int				*param;     /*pointer to FPGA register or DSP local variable*/
};

struct dm_flt_params
{
	int				dim;        /*array size of the parameter or curve */
	float			ll;			/*lower limit on value*/
	float			ul;			/*upper limit on value*/
	float			dflt;		/*default value */
	float			*sm_rdg;    /*pointer to parameter reading in shared memory*/
	float			*sm_set;	/*pointer to parameter setting in shared memory*/
	float		 	*flsh_val;  /*pointer to the flash memory storage*/
	float			*param;     /*pointer to FPGA register or DSP local variable*/
};

/* =========== Function Prototypes ================= */
	int setup_params(void);	
	int updateparams(void);
	int restoreparams(void);
	
	void StartCycleIntrpt(int dummy);
	void CycleTimerIntrpt(int dummy);
	
	int message2(char *msg);
	char msg_str[MAXMSGLEN];  // message string (global character array variable)
	int pause(int counts);
	
#endif //_PARAMHDR	
